/*
 * [EN]
 * Copyright (C) Kyros Technologies, Inc - All Rights Reserved
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [NR]
 * Copyright (C) Kyros Technologies, Inc - Alle rettigheter reservert
 *
 * Uautorisert kopiering av denne filen, via hvilket som helst medium, er strengt forbudt
 * Egen og konfidensiell
 * Skrevet av Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [PT-BR]
 * Copyright (C) Kyros Technologies, Inc - Todos os direitos reservados
 *
 * Cópias não autorizadas deste arquivo, através de qualquer meio é estritamente proibido
 * Confidenciais e proprietários
 * Escrito por Kim Ruan <kimr@kyros.com.br>, Abril 2018
 */

import b64 from 'base-64';
import _ from 'lodash';

import unlogged from '../config/unlogged';
import { setToken } from '../config/logged';
import { User } from '../classes/User';
import { errorRequestTreatment } from '../global/errors';

const authenticateRequest = ({ email, password }) => {
    let body = {
        'email'    : email,
        'password' : b64.encode(password),
        'type'     : 'MOBILE'
    };

    return unlogged.post('/login', body)
        .then(res => {
            let headers = res.headers;
            let data    = res.data;
            let message = data.message;

            if (_.has(headers, 'x-token')) {
                let user = new User(data.object);
                let token  = _.get(headers, 'x-token');
                setToken(token);
                return {
                    result : 'LOGIN_SUCCESS',
                    data   : {
                        message : message,
                        token   : token,
                        user    : user
                    }
                };
            }
            return {
                result : 'LOGIN_FAIL',
                data   : message
            };
        })
        .catch(error => { return errorRequestTreatment(error, 'LOGIN') });
};

export function makeLogin( email, password ) {
    return authenticateRequest({email, password})
        .then(async (res) => {
            let result = {};

            if (res.result === 'LOGIN_SUCCESS') {
                result = {
                    login_success : true,
                    message       : res.data.message,
                    token         : res.data.token,
                    user          : res.data.user
                }
            }
            else if (res.result === 'LOGIN_FAIL') {
                result = {
                    login_success : false,
                    message       : res.data,
                    token         : null,
                    user          : null
                }
            }

            return result
        });
}

module.exports = {
    makeLogin
};
