/*
 * [EN]
 * Copyright (C) Kyros Technologies, Inc - All Rights Reserved
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [NR]
 * Copyright (C) Kyros Technologies, Inc - Alle rettigheter reservert
 *
 * Uautorisert kopiering av denne filen, via hvilket som helst medium, er strengt forbudt
 * Egen og konfidensiell
 * Skrevet av Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [PT-BR]
 * Copyright (C) Kyros Technologies, Inc - Todos os direitos reservados
 *
 * Cópias não autorizadas deste arquivo, através de qualquer meio é estritamente proibido
 * Confidenciais e proprietários
 * Escrito por Kim Ruan <kimr@kyros.com.br>, Abril 2018
 */

import _ from 'lodash';

import logged, { setToken } from '../config/logged';
import { Player } from '../classes/Player';
import { errorRequestTreatment } from '../global/errors';
import { validateEmail } from '../global/validators';

const getPlayersRequest = ({ departmentId, teamId, name, pageSize, page, email, functionId }) => {

    let url = '';
    let passed = false;

    if (departmentId) {
        if (passed) url = url + '&departmentId=' + departmentId;
        else {
            url = '?departmentId=' + departmentId;
            passed = true;
        }
    }
    if (teamId) {
        if (passed) url = url + '&teamId=' + teamId;
        else {
            url = '?teamId=' + teamId;
            passed = true;
        }
    }
    if (name) {
        if (passed) url = url + '&name=' + name;
        else {
            url = '?name=' + name;
            passed = true;
        }
    }
    if (pageSize) {
        if (passed) url = url + '&pageSize=' + pageSize;
        else {
            url = '?pageSize=' + pageSize;
            passed = true;
        }
    }
    if (page) {
        if (passed) url = url + '&page=' + page;
        else {
            url = '?page=' + page;
            passed = true;
        }
    }
    if (email) {
        if (validateEmail(email)) {
            if (passed) url = url + '&email=' + email;
            else {
                url = '?email=' + email;
                passed = true;
            }
        }
        else return Promise.resolve({
            result  : 'GET_ALL_PLAYERS_FAIL',
            message : 'E-mail inválido!',
            players : null
        })
    }
    if (functionId) {
        if (passed) url = url + '&functionId=' + functionId;
        else {
            url = '?functionId=' + functionId;
            passed = true;
        }
    }

    return logged.get('/user' + url)
        .then(res => {
            let headers = res.headers;
            let data    = res.data;
            let message = data.message;
            let object  = data.object;

            if (object.totalFound > 0) {
                let listOfPlayers = object.list;
                let players = [];
                let token  = _.get(headers, 'x-token');

                listOfPlayers.map(player => players.push(new Player(player)));

                setToken(token);

                return {
                    result  : 'GET_ALL_PLAYERS_SUCCESS',
                    message : message,
                    token   : token,
                    players : players
                }
            }

            return {
                result  : 'GET_ALL_PLAYERS_FAIL',
                message : message,
            }
        })
        .catch(error => { return errorRequestTreatment(error, 'GET_ALL_PLAYERS') });
};

export function getAllPlayers(departmentId, teamId, name, pageSize, page, email, functionId) {
    return getPlayersRequest({ departmentId: departmentId, teamId: teamId, name: name, pageSize: pageSize, page: page, email: email, functionId: functionId })
        .then(async (res) => {
            let result = {};

            if (res.result === 'GET_ALL_PLAYERS_SUCCESS') {
                result = {
                    message  : res.message,
                    players  : res.players,
                    newToken : res.token
                }
            }
            else if (res.result === 'GET_ALL_PLAYERS_FAIL') {
                result = {
                    message  : res.message,
                    players  : null,
                    newToken : null
                }
            }

            return result
        });
}

module.exports = {
    getAllPlayers
};
